NonContiguousError

Type Alias NonContiguousError 

pub type NonContiguousError = AsSliceError;
๐Ÿ‘ŽDeprecated since 0.28.0:

use AsSliceError instead

Deprecated type alias to AsSliceError. The new name is preferred because arrays might also fail to view as a slice due to misalignment.

Aliased Type

pub struct NonContiguousError;